@@ -85,7 +85,7 @@ class Goppa():
 
     def __init__(self, gf: GF2, g: Poly, alpha: list["GF2Point"]):
         if not all(map(lambda x: x in gf, alpha)):
-            raise ValueError(f"{x}: alpha must be a list of elements from the Galois field!")
+            raise ValueError("All elements of alpha must be from the Galois field!")
         if not g.rabin_test():
             raise ValueError("The polynomial g must be irreducible!")
         self.gf = gf  # underlying Galois field
@@ -102,7 +102,7 @@ class Goppa():
         self.G = gen2pchk(self.H)
 
     def __repr__(self):
-        return f"Binary irreducible Goppa code over GF(2^{self.gf.power}) with polynomial g(x) = {self.g}."
+        return f"Binary irreducible Goppa [{self.G.cols}, {self.G.rows}] code over GF(2^{self.gf.degree}) with polynomial g(x) = {self.g}."
 
     def encode(self, x: list[int]):
         "Encode a given list of bits."
@@ -166,16 +166,14 @@ class CyclicCode():
         if n < 2:
             raise ValueError(f"Code lenght {n} must be at least 2!")
         zero = 0 * g[0]
-        try:
+        if hasattr(zero, "ring"):
             order = zero.ring.n  # Zmod
-        except:
-            try:
-                order = zero.field.order  # GF2
-            except:
-                try:
-                    order = type(zero).order  # galois
-                except:
-                    raise ValueError("Unknown base filed!")
+        elif hasattr(zero, "field"):
+            order = zero.field.order  # GF2
+        elif hasattr(type(zero), "order"):
+            order = type(zero).order  # galois
+        else:
+            raise ValueError("Unknown base field!")
         self.order = order  # order of the base field
         one = zero**0
         modulus = Poly([-one] + [zero] * (n-1) + [one])
@@ -189,7 +187,7 @@ class CyclicCode():
 
     def __repr__(self):
         return f"Cyclic [{self.n}, {self.k}] code over GF({self.order}) with generator polynomial g(x) = {self.g}."
-    
+
     def encode(self, x: list|Poly, gf = None, systematic_form = False):
         "Encode a given list or polynomial."
         as_list = False
@@ -219,7 +217,7 @@ class CyclicCode():
             raise ValueError(f"Degree can be at most {self.n-1}.")
         x, r = y.divmod(self.g)
         if r:
-            raise NotImplementedError(f"Word is no code word! Cannot decode.")
+            raise NotImplementedError("Word is no code word! Cannot decode.")
         if systematic_form:
             x.coeff = y.coeff[self.g.degree():]
         if as_list:
@@ -248,32 +246,32 @@ class ReedSolomonCode(CyclicCode):
     >>> rsc = ReedSolomonCode(k, gf)
     
     To encode a list of letters (the length must be equal to the dimension k of the code; conversion to the Galois field is done automatically):
-    >>> cc.encode([1, 2, 3])
-    [0, 1, 1, 0]
+    >>> rsc.encode([1, 2, 3])
+    [6, 4, 5, 1, 8, 4, 2, 9, 2, 8, 9, 6]
 
-    Decoding is only implemnted for code words:
-    >>> cc.decode([0, 1, 1, 0], ring = Zmod(2))
-    [0, 1, 0]
+    To decoding use:
+    >>> rsc.decode([1, 4, 4, 0, 8, 4, 2, 9, 2, 0, 9, 6])
+    [1, 2, 3]
     
     """
-    def __init__(self, k:int, gf, alpha = None):
+    def __init__(self, k:int, gf, alpha = None):  # pylint: disable=W0231
         zero = gf(0)
         one = zero**0
-        self. gf = gf
-        try:
-            n = gf.order()
-        except:
-            n = gf.order - 1
+        self.gf = gf
+        if hasattr(gf, "n"):
+            n = gf.n - 1  # Zmod
+        else:
+            n = gf.order - 1  # GF2|galois
         self.order = n + 1  # order of the base field
         self.n = n  # lenght
         self.k = k  # dimension
         self.d = n - k - 1  # minimal distance
         self.modulus = Poly([-one] + [zero] * (n-1) + [one])
         if alpha is None:
-            try:
-                alpha = gf.generator()  # Zmod|GF2
-            except:
+            if hasattr(gf, "primitive_element"):
                 alpha = gf.primitive_element  # galois
+            else:
+                alpha = gf.generator()  # Zmod|GF2
         self.alpha = alpha
         self.g = prod([Poly([-alpha**j, one]) for j in range(1,n-k+1)], start = one) # generating polynomial
         self.h = Poly(self.modulus) // self.g  # check polynomial
@@ -281,9 +279,9 @@ class ReedSolomonCode(CyclicCode):
         assert self.g * self.h == self.modulus
 
     def __repr__(self):
-        return f"Reed-Solomon-Code [{self.n}, {self.k}, {self.d}] over GF({self.n+1})."
+        return f"Reed-Solomon [{self.n}, {self.k}, {self.d}] code over GF({self.n+1})."
 
-    def encode(self, x: list|Poly):
+    def encode(self, x: list|Poly) -> list|Poly:  # pylint: disable=W0221
         "Encode a given list or polynomial."
         as_list = False
         zero = 0 * self.g[0]
@@ -297,7 +295,7 @@ class ReedSolomonCode(CyclicCode):
             return y + [zero] * (self.n - len(y))
         return Poly(y)
 
-    def decode(self, y: list|Poly):
+    def decode(self, y: list|Poly) -> list|Poly:  # pylint: disable=W0221
         "Decode a given list or polynomial."
         as_list = False
         zero = 0 * self.g[0]
