@@ -5,8 +5,6 @@ Polynomials
 from math import prod
 from numbers import Number
 from random import randint
-from .primes import is_prime
-
 
 class Poly:
     """
@@ -37,7 +35,7 @@ class Poly:
 
     def __call__(self, x):
         result = 0 * self.coeff[0]
-        if not type(x) == type(result):
+        if not type(x) == type(result):  # pylint: disable=C0123
             raise ValueError(
                 "Evaluation point must be an element of the ring.")
         # Horner's method
@@ -45,8 +43,6 @@ class Poly:
             result = result * x + c
         return result
 
-        return sum((c * x**j for j, c in enumerate(self.coeff)), start=zero)
-
     def __getitem__(self, item):
         if item >= len(self.coeff):
             return self.coeff[0] * 0
@@ -60,7 +56,7 @@ class Poly:
 
     def __iter__(self):
         yield from self.coeff
-        
+
     def __len__(self):
         return len(self.coeff)
 
@@ -100,7 +96,7 @@ class Poly:
                     tmp += plus + "- " + prx(i)
                     plus = " + "
                     continue
-            except:
+            except:  # pylint: disable=W0702
                 pass
             try:
                 if plus and s < 0:
@@ -108,7 +104,7 @@ class Poly:
                     if i != 0:
                         tmp += " " + prx(i)
                     continue
-            except:
+            except:  # pylint: disable=W0702
                 pass
             tmp += plus + str(s)
             if i != 0:
@@ -116,10 +112,10 @@ class Poly:
             plus = " + "
         return tmp.strip()
 
-    def _repr_mimebundle_(self, **kwargs):
+    def _repr_mimebundle_(self, **kwargs):  # pylint: disable=W0613
         return {
             "text/plain": repr(self),
-            "text/latex": "$" + self.__repr__(latex=True) + "$"
+            "text/latex": "$" + self.__repr__(latex=True) + "$"  # pylint: disable=C2801
         }
 
     def __eq__(self, other):
@@ -134,6 +130,10 @@ class Poly:
         "Return the degree."
         return len(self.coeff) - 1
 
+    def weight(self) -> int:
+        "Return the number of nonzero coefficients."
+        return sum(map(bool,self.coeff))
+
     def map(self, func):
         "Apply a given function to all coefficients in place."
         self.coeff = list(map(func, self.coeff))
@@ -143,21 +143,19 @@ class Poly:
         return self.__class__(list(map(func, self.coeff)), modulus=self.modulus)
 
     def _check_type(self, other):
-        return isinstance(other, int) or (isinstance(other, Number) and isinstance(self.coeff[0], Number)) or type(other) == type(self.coeff[0])
+        return isinstance(other, int) or (isinstance(other, Number) and isinstance(self.coeff[0], Number)) or type(other) == type(self.coeff[0])  # pylint: disable=C0123
 
     def _guess_ring(self):
         zero = 0 * self.coeff[0]
         one = zero**0
-        try:
+        if hasattr(zero, "ring"):
             ring = zero.ring  # Zmod
-        except:
-            try:
-                ring = zero.field  # GF2
-            except:
-                try:
-                    ring = type(zero)  # galois
-                except:
-                    ring = None
+        elif hasattr(zero, "field"):
+            ring = zero.field  # GF2
+        elif hasattr(type(zero), "order"):
+            ring = type(zero)  # galois
+        else:
+            ring = None
         return zero, one, ring
 
     def _guess_field(self):
@@ -213,7 +211,7 @@ class Poly:
             return NotImplemented
         zero = 0 * self.coeff[0]
         ls, lo = len(self.coeff), len(other.coeff)
-        coeff = [sum((self.coeff[j] * other.coeff[k - j] for j in range(max(0, k - lo + 1), min(ls, k + 1))), start=zero) 
+        coeff = [sum((self.coeff[j] * other.coeff[k - j] for j in range(max(0, k - lo + 1), min(ls, k + 1))), start=zero)
                      for k in range(ls + lo - 1)]
         modulus = self.modulus
         if not modulus and other.modulus:
@@ -369,10 +367,8 @@ class Poly:
 
     def gcd(self, other: "Poly") -> "Poly":
         "Greates common divisor with a given polynomial."
-        ring = self._guess_ring()[-1]
         if not isinstance(other, self.__class__):
-            raise NotImplementedError(f"Cannot compute gcd: {
-                                      other} must be a polynomial.")
+            raise NotImplementedError(f"Cannot compute gcd: {other} must be a polynomial.")
         if not self:
             if not other:
                 return Poly([self.coeff[0]])
@@ -387,10 +383,9 @@ class Poly:
 
     def egcd(self, other: "Poly") -> ("Poly", "Poly", "Poly"):
         """Perform the extended Euclidean agorithm for polynomials. Returns gcd, x, y such that other * x + self * y = gcd."""
-        zero, one, ring = self._guess_ring()
+        zero, one, _ = self._guess_ring()
         if not isinstance(other, self.__class__):
-            raise NotImplementedError(f"Cannot perform egcd: {
-                                      other} must be a polynomial.")
+            raise NotImplementedError(f"Cannot perform egcd: {other} must be a polynomial.")
         if not self:
             if not other:
                 return Poly([zero]), Poly([zero]), Poly([zero])
@@ -493,7 +488,7 @@ class Poly:
 
     def equal_degree_factors(self, k: int) -> list:
         "Factors a square free product of irreducibel polynomials of degree `k` over a Galois field."
-        field, zero, one, q, p = self._guess_field()
+        field, _, one, q, p = self._guess_field()
         if hasattr(field, "degree"):
             degree = field.degree
         else:
@@ -506,7 +501,6 @@ class Poly:
                 f"The polynomial is no product of irreducibel polynomials of degree {k}.")
         r = d // k
         qk = (q**k - 1) // 2
-        poly = [0] * k + [1]
 
         factors = [self]
         while len(factors) < r:
@@ -514,11 +508,11 @@ class Poly:
                      for _ in range(d+1)], ring=field, modulus=self)
             if p == 2:  # Gathen-Shoup
                 h = g
-                for i in range(1, k):
+                for _ in range(1, k):
                     g += h**q
                 if degree > 1:
                     h = g
-                    for i in range(1, degree):
+                    for _ in range(1, degree):
                         g += g**2
             else:  # Cantor–Zassenhaus
                 g = g**qk - one
