@@ -1,5 +1,6 @@
-import pytest
-from random import randint, seed
+# pragma pylint: disable=C0114,C0116
+import pytest  # pylint: disable=W0611
+from random import randint, seed  # pylint: disable=C0411
 from kryptools import GF2, euler_phi
 seed(0)
 
@@ -11,8 +12,8 @@ def test_GF2_ops():
         assert gf(1)
         assert not gf(0)
         assert gf(1) == gf(1)
-        assert not gf(1) == gf(0)
-        assert not gf(0) == 0
+        assert gf(1) != gf(0)
+        assert gf(0) != 0
         if gf.degree < 17:
             assert len(list(gf)) == gf.order
             assert len(list(gf.star())) == gf.order - 1
@@ -29,9 +30,9 @@ def test_GF2_ops():
                 assert (a / b).poly() == a.poly() / b.poly()
             assert a.sqrt()**2 == a
         with pytest.raises(ValueError):
-            gf(1) / gf(0)
+            gf(1) / gf(0)  # pylint: disable=W0106
         with pytest.raises(ValueError):
-            gf(0)**-1
+            gf(0)**-1  # pylint: disable=W0106
 
 def test_GF2_order():
     for n in range(1, 8):
