@@ -1,5 +1,6 @@
-import pytest
-from fractions import Fraction
+# pragma pylint: disable=C0114,C0116
+import pytest  # pylint: disable=W0611
+from fractions import Fraction  # pylint: disable=C0411
 from kryptools import Matrix, Zmod
 
 
@@ -7,7 +8,7 @@ def test_Matrix():
     M = Matrix([[1, 2, 3], [4, 5, 6], [7, 8, 12]])
     Z = M.zeros()
     assert M
-    assert M == M
+    assert M == M + Z
     assert not Z
     Z[0] = 1
     assert Z
